@@ -3,17 +3,14 @@
     Project              : Knights
     Description          : Main window of the application
     --------------------------------------------------------------------
-    Copyright            : (C) 2016-1018 by Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2010-2012 by Miha Čančula (miha@noughmad.eu)
+    SPDX-FileCopyrightText: 2016-1018 Alexander Semke (alexander.semke@web.de)
+    SPDX-FileCopyrightText: 2010-2012 Miha Čančula (miha@noughmad.eu)
 
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  *                                                                         *
  *  This program is distributed in the hope that it will be useful,        *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
@@ -468,7 +465,8 @@ void MainWindow::optionsPreferences() {
 // 	ui_prefs_access.setupUi(accessDlg);
 // 	dialog->addPage(accessDlg, i18n("Accessibility"), QLatin1String("preferences-desktop-accessibility"));
 
-	QWidget* themeDlg = new KgThemeSelector(m_themeProvider, KgThemeSelector::EnableNewStuffDownload, dialog);
+    KgThemeSelector* themeDlg = new KgThemeSelector(m_themeProvider, KgThemeSelector::EnableNewStuffDownload, dialog);
+    themeDlg->setNewStuffConfigFileName(QStringLiteral("knights.knsrc"));
 	dialog->addPage(themeDlg, i18n("Theme"), QStringLiteral("games-config-theme"));
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 
